"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const loader_utils_1 = require("loader-utils");
const schema_utils_1 = require("schema-utils");
const core = require("./core");
const options = require("./options");
const LOADER_NAME = "git-lfs-loader";
const MAX_CONTENT_LENGTH = 1000;
function run(loaderContext, content) {
    if (content.length > MAX_CONTENT_LENGTH) {
        return content;
    }
    const optionsFromUser = loader_utils_1.getOptions(loaderContext);
    schema_utils_1.validate(options.SCHEMA, optionsFromUser, {
        name: LOADER_NAME,
        baseDataPath: "options",
    });
    const severity = {
        errorEncountered: defaultTo(options.DEFAULT_SEVERITY.errorEncountered, optionsFromUser.errorEncountered),
        pointerFileFound: defaultTo(options.DEFAULT_SEVERITY.pointerFileFound, optionsFromUser.pointerFileFound),
    };
    handleResult(loaderContext, severity, core.isGitLfsPointerFile(content));
    return content;
}
exports.run = run;
function handleResult(loaderContext, severity, result) {
    switch (result._) {
        case "success":
            if (result.isPointerFile) {
                handleError(loaderContext, severity.pointerFileFound, `This looks like a ${core.gitLfsPointerFile}. You may want to run 'git lfs pull' to checkout the actual file.`);
            }
            break;
        case "failure":
            handleError(loaderContext, severity.errorEncountered, `Could not check if this is a ${core.gitLfsPointerFile}. ${result.error.message}`);
            break;
        default:
            ((x) => { throw x; })(result);
    }
}
function handleError(loaderContext, severity, errorMessage) {
    const error = new Error(errorMessage);
    switch (severity) {
        case "error":
            loaderContext.emitError(error);
            break;
        case "warning":
            loaderContext.emitWarning(error);
            break;
        default:
            ((x) => { throw x; })(severity);
    }
}
function defaultTo(def, x) {
    return x === undefined ? def : x;
}
